==> openshift-model-operatorhub-6.9.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StepResourceFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class StepResourceFluent<A extends StepResourceFluent<A>> extends BaseFluent<A>{
  public StepResourceFluent() {
  }
  
  public StepResourceFluent(StepResource instance) {
    this.copyInstance(instance);
  }
  private String group;
  private String kind;
  private String manifest;
  private String name;
  private String sourceName;
  private String sourceNamespace;
  private String version;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(StepResource instance) {
    instance = (instance != null ? instance : new StepResource());
  
    if (instance != null) {
        this.withGroup(instance.getGroup());
        this.withKind(instance.getKind());
        this.withManifest(instance.getManifest());
        this.withName(instance.getName());
        this.withSourceName(instance.getSourceName());
        this.withSourceNamespace(instance.getSourceNamespace());
        this.withVersion(instance.getVersion());
        this.withGroup(instance.getGroup());
        this.withKind(instance.getKind());
        this.withManifest(instance.getManifest());
        this.withName(instance.getName());
        this.withSourceName(instance.getSourceName());
        this.withSourceNamespace(instance.getSourceNamespace());
        this.withVersion(instance.getVersion());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getGroup() {
    return this.group;
  }
  
  public A withGroup(String group) {
    this.group=group; return (A) this;
  }
  
  public boolean hasGroup() {
    return this.group != null;
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public String getManifest() {
    return this.manifest;
  }
  
  public A withManifest(String manifest) {
    this.manifest=manifest; return (A) this;
  }
  
  public boolean hasManifest() {
    return this.manifest != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getSourceName() {
    return this.sourceName;
  }
  
  public A withSourceName(String sourceName) {
    this.sourceName=sourceName; return (A) this;
  }
  
  public boolean hasSourceName() {
    return this.sourceName != null;
  }
  
  public String getSourceNamespace() {
    return this.sourceNamespace;
  }
  
  public A withSourceNamespace(String sourceNamespace) {
    this.sourceNamespace=sourceNamespace; return (A) this;
  }
  
  public boolean hasSourceNamespace() {
    return this.sourceNamespace != null;
  }
  
  public String getVersion() {
    return this.version;
  }
  
  public A withVersion(String version) {
    this.version=version; return (A) this;
  }
  
  public boolean hasVersion() {
    return this.version != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StepResourceFluent that = (StepResourceFluent) o;
    if (!java.util.Objects.equals(group, that.group)) return false;
  
    if (!java.util.Objects.equals(kind, that.kind)) return false;
  
    if (!java.util.Objects.equals(manifest, that.manifest)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(sourceName, that.sourceName)) return false;
  
    if (!java.util.Objects.equals(sourceNamespace, that.sourceNamespace)) return false;
  
    if (!java.util.Objects.equals(version, that.version)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(group,  kind,  manifest,  name,  sourceName,  sourceNamespace,  version,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (group != null) { sb.append("group:"); sb.append(group + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (manifest != null) { sb.append("manifest:"); sb.append(manifest + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (sourceName != null) { sb.append("sourceName:"); sb.append(sourceName + ","); }
    if (sourceNamespace != null) { sb.append("sourceNamespace:"); sb.append(sourceNamespace + ","); }
    if (version != null) { sb.append("version:"); sb.append(version + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-operatorhub-6.9.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StepResourceFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class StepResourceFluent<A extends StepResourceFluent<A>> extends BaseFluent<A>{
  public StepResourceFluent() {
  }
  
  public StepResourceFluent(StepResource instance) {
    this.copyInstance(instance);
  }
  private String group;
  private String kind;
  private String manifest;
  private String name;
  private String sourceName;
  private String sourceNamespace;
  private String version;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(StepResource instance) {
    instance = (instance != null ? instance : new StepResource());
    if (instance != null) {
          this.withGroup(instance.getGroup());
          this.withKind(instance.getKind());
          this.withManifest(instance.getManifest());
          this.withName(instance.getName());
          this.withSourceName(instance.getSourceName());
          this.withSourceNamespace(instance.getSourceNamespace());
          this.withVersion(instance.getVersion());
          this.withGroup(instance.getGroup());
          this.withKind(instance.getKind());
          this.withManifest(instance.getManifest());
          this.withName(instance.getName());
          this.withSourceName(instance.getSourceName());
          this.withSourceNamespace(instance.getSourceNamespace());
          this.withVersion(instance.getVersion());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getGroup() {
    return this.group;
  }
  
  public A withGroup(String group) {
    this.group = group;
    return (A) this;
  }
  
  public boolean hasGroup() {
    return this.group != null;
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind = kind;
    return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public String getManifest() {
    return this.manifest;
  }
  
  public A withManifest(String manifest) {
    this.manifest = manifest;
    return (A) this;
  }
  
  public boolean hasManifest() {
    return this.manifest != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getSourceName() {
    return this.sourceName;
  }
  
  public A withSourceName(String sourceName) {
    this.sourceName = sourceName;
    return (A) this;
  }
  
  public boolean hasSourceName() {
    return this.sourceName != null;
  }
  
  public String getSourceNamespace() {
    return this.sourceNamespace;
  }
  
  public A withSourceNamespace(String sourceNamespace) {
    this.sourceNamespace = sourceNamespace;
    return (A) this;
  }
  
  public boolean hasSourceNamespace() {
    return this.sourceNamespace != null;
  }
  
  public String getVersion() {
    return this.version;
  }
  
  public A withVersion(String version) {
    this.version = version;
    return (A) this;
  }
  
  public boolean hasVersion() {
    return this.version != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StepResourceFluent that = (StepResourceFluent) o;
    if (!java.util.Objects.equals(group, that.group)) return false;
    if (!java.util.Objects.equals(kind, that.kind)) return false;
    if (!java.util.Objects.equals(manifest, that.manifest)) return false;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(sourceName, that.sourceName)) return false;
    if (!java.util.Objects.equals(sourceNamespace, that.sourceNamespace)) return false;
    if (!java.util.Objects.equals(version, that.version)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(group,  kind,  manifest,  name,  sourceName,  sourceNamespace,  version,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (group != null) { sb.append("group:"); sb.append(group + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (manifest != null) { sb.append("manifest:"); sb.append(manifest + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (sourceName != null) { sb.append("sourceName:"); sb.append(sourceName + ","); }
    if (sourceNamespace != null) { sb.append("sourceNamespace:"); sb.append(sourceNamespace + ","); }
    if (version != null) { sb.append("version:"); sb.append(version + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
